<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor del sistema</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Monitor del sistema de Deepin es una herramienta para monitorear la carga del sistema en tiempo real, ver y controlar los procesos y servicios que se ejecutan en su sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Ocultar detalles</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Escritura</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 días %2 horas %3 minutos</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Utilización</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frecuencia actual</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Zócalos</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Procesadores lógicos</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualización</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Caché L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Caché L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Caché L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Caché L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Promedio de carga</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Descriptores de archivo</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Procesos</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Hilos</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nombre de anfitrión</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Tipo de sistema</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Tiempo de disponibilidad</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>No hay resultados de búsqueda</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>activo</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>recargando</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inactivo</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>falló</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>activando</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>desactivando</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>talón</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>no-encontrado</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>mal-ajuste</translation>
    </message>
    <message>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>fusionado</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>enmascarado</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>cargado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>habilitado</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>inhabilitado</translation>
    </message>
    <message>
        <source>static</source>
        <translation>estático</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transitorio</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirecto</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>habilitado-tiempo-de-ejecución</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>enmascarado</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>generado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>muerto</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>pre-inicio</translation>
    </message>
    <message>
        <source>start</source>
        <translation>inicio</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>iniciar-entrada</translation>
    </message>
    <message>
        <source>running</source>
        <translation>ejecutando</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>salido</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>recarga</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>alto</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>detener-perro-guardián</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>detener-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>detener-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>detener-entrada</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>finalizar-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>finalizar-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>falló</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-reinicio</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Usado</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Compartido</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>En caché</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Búferes</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Intercambio en caché</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Sucio</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapeado</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Intercambio total</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Intercambio libre</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Losa</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Velocidad de lectura</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Velocidad de escritura</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capacidad</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Sectores leídos</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Lecturas/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sectores leídos/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Lecturas fusionadas/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sectores escritos</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Escrituras completas</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Escrituras fusionadas</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Escrituras/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sectores escritos/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Escrituras fusionadas/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Terminar este proceso puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Terminar proceso</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forzar el cierre del proceso puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forzar el cierre de la aplicación puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Forzar cierre</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Finalizar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Dirección IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Máscara de red:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Emisión:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Longitud de prefijo:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Alcance:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Tipo de conexión</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Calidad de enlace</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Fuerza de la señal</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Nivel de ruido</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Ancho de banda</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paquetes RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bytes RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Errores RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX abandonados</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX desbordados</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>cuadro RX</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paquetes TX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bytes TX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Errores TX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX desbordados</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX portadora</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX cayó</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Línea de comandos</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Tiempo de inicio</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clic en la aplicación que quiere cerrar</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Recibido</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura del disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura del disco</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inhabilitado</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subido</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Total recibido</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Total enviado</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Muy alto</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Regular</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>No se modificó la prioridad del proceso</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mis procesos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos los procesos</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>No se ha podido detener el proceso</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>No se reanudó el proceso</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Fallo la eliminación del proceso</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Falló en el envío de la señal para procesar</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>No se pudo terminar el proceso</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplicaciones y %2 procesos en ejecución)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>No responde</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendido</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Ver ubicación del comando</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Terminar proceso</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reanudar proceso</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Matar proceso</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Cambiar prioridad</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender proceso</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Prioridad personalizada</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Cambiar</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura del disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura del disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>NI</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Memoria compartida</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Memoria virtual</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>No compatible</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Error al establecer el tipo de inicio del servicio</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: Falla al establecer el tipo de inicio del servicio debido al subproceso bloqueado.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nombre de instancia del servicio</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Tipo de inicio</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Ejecución</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Tipo de inicio</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Forzar cierre de aplicación</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandida</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compacta</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Procesos</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Servicios</translation>
    </message>
</context>
</TS>
